Module pattern

Module pattern 

Pattern syntax onboarding for pelite-style signatures.

goblin-sigscan re-exports the parser from goblin-sigscan-pattern so callers can parse at runtime or use pattern! for compile-time parsing.

Structs

ParsePatError
Pattern parser error.

Enums

Atom
Pattern atoms.
PatError
Pattern parsing error categories.

Functions

parse
Parses a pelite-style signature string into atoms.
save_len
Returns the save array length required by the pattern.

Type Aliases

Pattern
Patterns are a list of Atoms.